@@ -18,19 +18,22 @@ sub message {
 
 sub serialize {
     my (undef, $input, $is_key) = @_;
-    return join( '', 
-        !defined($input) ?
-            'undef'.($is_key ? ' => ' : ', ')
-        : ref($input) eq 'ARRAY' ? 
-            ( '[ ', ( map { 
-                ( t_LKT_Util->serialize( $_ ) ) 
-            } @{$input} ), '], ' ) 
-        : ref($input) eq 'HASH' ? 
-            ( '{ ', ( map { 
-                ( t_LKT_Util->serialize( $_, 1 ), t_LKT_Util->serialize( $input->{$_} ) ) 
-            } sort keys %{$input} ), '}, ' ) 
-        : '\''.$input.'\''.($is_key ? ' => ' : ', ')
-    );
+    return join q{},
+        !defined $input
+            ? 'undef' . ($is_key ? ' => ' : ', ')
+        : ref $input eq 'ARRAY'
+            ? ( '[ ', ( map {
+                  ( t_LKT_Util->serialize( $_ ) )
+              } @{$input} ), '], ' )
+        : ref $input eq 'HASH'
+            ? ( '{ ', ( map {
+                  ( t_LKT_Util->serialize( $_, 1 ),
+                    t_LKT_Util->serialize( $input->{$_} ) )
+              } sort keys %{$input} ), '}, ' )
+        :
+              ($input eq q{} ? 'q{}' : qq{'$input'})
+              . ($is_key ? ' => ' : ', ')
+        ;
 }
 
 ######################################################################
